#!/bin/ksh
#
# Make an HTML file to index the CAMRa quicklooks in the current
# directory for the tape number specified on the command line.
# The HTML is sent to standard output.
#

if [ "$#" -gt 0 ]
then
    TAPE=$1
else
    echo "Usage: $0 tape_num"
    exit
fi

if [ -r title ]
then
   TITLE=$(cat title)
else
   TITLE="Quicklooks from the Chilbolton 3-GHz radar: Tape $TAPE"
fi

#BARFILE=/home/radar/public_html/bar_quicklooks.html
#cat $BARFILE | sed -e '/####/,$ d' -e "s/##TITLE##/$TITLE/"

echo "<HTML>
<HEAD><TITLE>$TITLE</TITLE></HEAD>
<BODY BGCOLOR=\"white\"><FONT FACE=\"helvetica, arial\">"

echo "<H1>$TITLE</H1>"

if [ -r info.html ]
then 
   cat info.html
   echo '<HR>'
fi

if [ -r options ]
then
   echo "<P>Processing options: <TT>$(cat options)</TT></P>"
fi

echo '<P>The information in each of the columns below is:</P>
<P><TT><B>Time at start of raster in UTC</B> (scan type) raster_number/scan_number</TT></P>'

#echo '<P>Contact <A HREF="mailto:R.J.Hogan@reading.ac.uk">Robin Hogan</A> if
#you have any queries. </P>'
echo '<HR>'

echo "<TABLE WIDTH=100%><TR><TD VALIGN=top><TT>"
MIDFILE=$(echo $TAPE*Zh.png | awk '{print $(1+NF/2)}')
for ZFILE in $TAPE*Zh.png
do
   UTC=$(echo $ZFILE | cut -c13-18)
   HOUR=$(echo $UTC | cut -c1-2)
   MIN=$(echo $UTC | cut -c3-4)
   SEC=$(echo $UTC | cut -c5-6)
   ZDRFILE=$(echo $ZFILE | sed s/Zh/Zdr/)
   LDRFILE=$(echo $ZFILE | sed s/Zh/Ldr/)
   FILEBASE=$(echo $ZFILE | cut -c1-12)
   VFILE=$(echo $FILEBASE*_v.png)
   VUNFFILE=$(echo $FILEBASE*_v_unfolded.png)
   V2FILE=$(echo $FILEBASE*_v2.png)
   PHIDPFILE=$(echo $FILEBASE*_phi_dp.png)
   RASTER=$(echo $ZFILE | cut -c6-8)
#   SCAN=$(echo $ZFILE | cut -c10-11 | sed 's/^0//')
   SCAN=$(echo $ZFILE | cut -c10-11)
   TYPE=$(echo $ZFILE | cut -c 20-22)
   if [ "$MIDFILE" = "$ZFILE" ]
   then
      echo "</TT></TD><TD VALIGN=top><TT>"
   fi
   if [ "$SCAN" = "01" ]
   then
      echo "<B>$HOUR:$MIN:$SEC</B> ($TYPE)"
   else
      echo ".............."
   fi
#   echo " $RASTER/$SCAN: <A HREF=$ZFILE>Z</A>|<A HREF=$ZDRFILE>ZDR</A>|<A HREF=$LDRFILE>LDR</A>|<A HREF=$V2FILE>V</A>|<A HREF=$PHIDPFILE>PHI_DP</A><BR>"
   echo " $RASTER/$SCAN: <A HREF=$ZFILE>Z</A>|<A HREF=$ZDRFILE>ZDR</A>|<A HREF=$LDRFILE>LDR</A>|<A HREF=$VFILE>V</A>|<A HREF=$VUNFFILE>V_UNFOLDED</A>|<A HREF=$PHIDPFILE>PHI_DP</A><BR>"
done

echo "</TD></TR></TABLE>"

echo "</TT>"
echo "</BODY>
</HTML>"
#cat $BARFILE | sed '1,/####/d'

